"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _helperPluginUtils = require("@babel/helper-plugin-utils");

var _camelCase = _interopRequireDefault(require("lodash/camelCase"));

var _snakeCase = _interopRequireDefault(require("lodash/snakeCase"));

var _seedrandom = _interopRequireDefault(require("seedrandom"));

var _animals = _interopRequireDefault(require("./words/animals.json"));

var _dinosaurs = _interopRequireDefault(require("./words/dinosaurs.json"));

var _fruits = _interopRequireDefault(require("./words/fruits.json"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

var wordLists = [{
  type: "animals",
  words: _animals["default"]
}, {
  type: "dinosaurs",
  words: _dinosaurs["default"]
}, {
  type: "fruits",
  words: _fruits["default"]
}];

var preserveCase = function preserveCase(targetCase, valueToFormat) {
  var camelCaseTarget = (0, _camelCase["default"])(targetCase) || "";

  if (camelCaseTarget === targetCase) {
    return (0, _camelCase["default"])(valueToFormat);
  } // PascalCase


  if ("".concat(camelCaseTarget[0].toUpperCase()).concat(camelCaseTarget.slice(1)) === targetCase) {
    var camelCaseValue = (0, _camelCase["default"])(valueToFormat);
    return "".concat(camelCaseValue[0].toUpperCase()).concat(camelCaseValue.slice(1));
  }

  if ((0, _snakeCase["default"])(targetCase) === targetCase) {
    return (0, _snakeCase["default"])(valueToFormat);
  }

  if ((0, _snakeCase["default"])(targetCase).toUpperCase() === targetCase) {
    return (0, _snakeCase["default"])(valueToFormat).toUpperCase();
  }

  return (0, _camelCase["default"])(valueToFormat);
};

var _default = (0, _helperPluginUtils.declare)(function (api, _ref) {
  var wordType = _ref.wordType,
      seed = _ref.seed;
  var usedIndexes = {
    animals: [],
    dinosaurs: [],
    fruits: []
  };
  var getListRandomNumber = (0, _seedrandom["default"])(seed);
  var getWordRandomNumber = (0, _seedrandom["default"])(seed);

  var getWord = function getWord() {
    var list = wordType ? wordLists.find(function (list) {
      return list.type === wordType;
    }) : wordLists[Math.floor(getListRandomNumber() * wordLists.length)];
    var wordIndex;

    while (wordIndex === undefined || usedIndexes[list.type].includes(wordIndex)) {
      wordIndex = Math.floor(getWordRandomNumber() * list.words.length);
    }

    usedIndexes[list.type].push(wordIndex);
    return list.words[wordIndex];
  };

  return {
    visitor: {
      VariableDeclaration: function VariableDeclaration(path) {
        path.node.declarations.forEach(function (declaration) {
          if (declaration.id.name && declaration.id.name !== "i") {
            path.scope.rename(declaration.id.name, preserveCase(declaration.id.name, getWord()));
          }
        });
      },
      FunctionDeclaration: function FunctionDeclaration(path) {
        path.scope.rename(path.node.id.name, preserveCase(path.node.id.name, getWord()));
        path.node.params.forEach(function (param) {
          if (param.name && param.name !== "props") {
            path.scope.rename(param.name, preserveCase(param.name, getWord()));
          }
        });
      },
      ClassDeclaration: function ClassDeclaration(path) {
        path.scope.rename(path.node.id.name, preserveCase(path.node.id.name, getWord()));
      },
      ArrowFunctionExpression: function ArrowFunctionExpression(path) {
        path.node.params.forEach(function (param) {
          if (param.name && param.name !== "props") {
            path.scope.rename(param.name, preserveCase(param.name, getWord()));
          }
        });
      },
      FunctionExpression: function FunctionExpression(path) {
        path.node.params.forEach(function (param) {
          if (param.name && param.name !== "props") {
            path.scope.rename(param.name, preserveCase(param.name, getWord()));
          }
        });
      },
      ObjectProperty: function ObjectProperty(path) {
        path.scope.rename(path.node.key.name, preserveCase(path.node.key.name, getWord()));
      },
      TSInterfaceDeclaration: function TSInterfaceDeclaration(path) {
        console.log(path);
        path.node.scope.rename(path.node.id.name, preserveCase(path.node.id.name, getWord()));
      }
    }
  };
});

exports["default"] = _default;